Type: Package
Package: conquestr
Title: An R Package to Extend 'ACER ConQuest'
Version: 1.3.0
Authors@R: c(
    person(
      given = "Dan",
      family = "Cloney",
      role = c("aut", "cre"),
      email = "dan.cloney@acer.org",
      comment = c(ORCID = "0000-0002-2130-237X")
    ),
    person(
      given = "Ray",
      family = "Adams",
      role = c("aut"),
      email = "ray.adams@acer.org"
    )
  )
Description: Extends 'ACER ConQuest' through a family of functions
    designed to improve graphical outputs and help with advanced analysis
    (e.g., differential item functioning).  Allows R users to call 
    'ACER ConQuest' from within R and read 'ACER ConQuest' System Files
    (generated by the command `put` <https://conquestmanual.acer.org/s4-00.html#put>).
    Requires 'ACER ConQuest' version 5.33.2 or later. 
    A demonstration version can be downloaded from <https://shop.acer.org/acer-conquest-5.html>.
License: GPL-3
URL: https://www.acer.org/au/conquest, https://conquestmanual.acer.org,
        https://shop.acer.org/acer-conquest-5.html
Imports: dplyr, ggplot2 (>= 3.3.0), ggrepel, kableExtra, magrittr,
        methods, Rcpp, rlang, stats, stringr, tidyr, tidyselect, zlib
Suggests: knitr, gridExtra, rmarkdown, testthat (>= 3.0.0)
LinkingTo: Rcpp
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.1
SystemRequirements: ACER ConQuest (>=5.34.3)
Collate: "RcppExports.R" "ReadConQuestLibrary.R"
        "ReadConQuestRout_createDF.R" "ReadConQuestState.R"
        "postProcessCqSysfile.R" "ReadConQuestState_createDF.R"
        "conquestr.R" "conquestrFunc.R" "generateHelpers.R"
        "infoHelpers.R" "itanalHelpers.R" "plotGeneral.R" "plotRout.R"
        "pvHelpers.R" "residHelpers.R" "showHelpers.R" "thrstThrsh.R"
        "cleaningHelpers.R"
NeedsCompilation: yes
Packaged: 2024-02-18 01:54:35 UTC; acercloneyd
Author: Dan Cloney [aut, cre] (<https://orcid.org/0000-0002-2130-237X>),
  Ray Adams [aut]
Maintainer: Dan Cloney <dan.cloney@acer.org>
Repository: CRAN
Date/Publication: 2024-02-18 03:20:02 UTC
Built: R 4.2.3; aarch64-apple-darwin20; 2024-02-18 06:28:43 UTC; unix
Archs: conquestr.so.dSYM
