Type: Package
Package: conquestr
Title: An R Package to Extend 'ACER ConQuest'
Version: 1.5.5
Authors@R: c(
    person(
      given = "Dan",
      family = "Cloney",
      role = c("aut", "cre"),
      email = "dan.cloney@acer.org",
      comment = c(ORCID = "0000-0002-2130-237X")
    ),
    person(
      given = "Ray",
      family = "Adams",
      role = c("aut"),
      email = "ray.adams@acer.org"
    )
  )
Description: Extends 'ACER ConQuest' through a family of functions
    designed to improve graphical outputs and help with advanced analysis
    (e.g., differential item functioning).  Allows R users to call 
    'ACER ConQuest' from within R and read 'ACER ConQuest' System Files
    (generated by the command `put` <https://conquestmanual.acer.org/s4-00.html#put>).
    Requires 'ACER ConQuest' version 5.40 or later. 
    A demonstration version can be downloaded from <https://shop.acer.org/acer-conquest-5.html>.
License: GPL-3
URL: https://www.acer.org/au/conquest, https://conquestmanual.acer.org,
        https://shop.acer.org/acer-conquest-5.html
Imports: dplyr, ggplot2 (>= 3.5.1), ggrepel, kableExtra, magrittr,
        methods, Rcpp, rlang, stats, stringr, tidyr, tidyselect, zlib
Suggests: knitr, gridExtra, rmarkdown, testthat (>= 3.2.1)
LinkingTo: Rcpp
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
SystemRequirements: ACER ConQuest (>=5.40.0)
Collate: "RcppExports.R" "ReadConQuestLibrary.R"
        "ReadConQuestRout_createDF.R" "ReadConQuestState.R"
        "postProcessCqSysfile.R" "ReadConQuestState_createDF.R"
        "conquestr.R" "conquestrFunc.R" "generateItems.R"
        "generateHelpers.R" "infoHelpers.R" "itanalHelpers.R"
        "plotGeneral.R" "plotRout.R" "pvHelpers.R" "residHelpers.R"
        "showHelpers.R" "thrstThrsh.R" "cleaningHelpers.R"
Depends: R (>= 4.1.0)
NeedsCompilation: yes
Packaged: 2025-08-22 15:23:37 UTC; acercloneyd
Author: Dan Cloney [aut, cre] (ORCID: <https://orcid.org/0000-0002-2130-237X>),
  Ray Adams [aut]
Maintainer: Dan Cloney <dan.cloney@acer.org>
Repository: CRAN
Date/Publication: 2025-08-23 23:10:16 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 17:16:23 UTC; unix
Archs: conquestr.so.dSYM
