# Generated by roxygen2: do not edit by hand

S3method(plotRout,ICC)
S3method(plotRout,InformationWithLatentDist)
S3method(plotRout,MCC)
S3method(plotRout,TestInfo)
S3method(plotRout,default)
export(plotRout)
exportPattern("^[[:alpha:]]+") 
if (.Platform$OS.type=="windows") importFrom(utils,shortPathName)
importFrom(Rcpp,sourceCpp)
importFrom(dplyr,across)
importFrom(dplyr,group_by)
importFrom(dplyr,matches)
importFrom(dplyr,mutate)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggplot_build)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme_bw)
importFrom(kableExtra,cell_spec)
importFrom(kableExtra,kable_styling)
importFrom(magrittr,"%>%")
importFrom(methods,hasArg)
importFrom(methods,is)
importFrom(rlang,.data)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,loess)
importFrom(stats,na.omit)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,qchisq)
importFrom(stats,reshape)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(stats,weighted.mean)
importFrom(tidyr,pivot_longer)
importFrom(tidyselect,everything)
importFrom(utils,str)
importFrom(zlib,decompress)
importFrom(zlib,decompressobj)
importFrom(zlib,zlib)
useDynLib(conquestr)
